"""Core parser app config
"""

from django.apps import AppConfig


class CoreParserAppConfig(AppConfig):
    name = "core_parser_app"
    verbose_name = "Core Parser App"
